#
# spec file for package python-qrcode
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-qrcode
Version:        8.2
Release:        1.1
Summary:        QR Code image generator
License:        BSD-3-Clause
URL:            https://github.com/lincolnloop/python-qrcode
Source:         %{url}/archive/v%{version}.tar.gz#/qrcode-%{version}.tar.gz
BuildRequires:  %{python_module Pillow >= 9.1.0}
BuildRequires:  %{python_module base >= 3.9}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core}
BuildRequires:  %{python_module pypng}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module typing-extensions}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Recommends:     python-Pillow >= 9.1.0
Recommends:     python-pypng
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
This module uses the Python Imaging Library (PIL) to allow for the generation
of QR Codes.

%prep
%setup -q -n python-qrcode-%{version}
# drop shebang from console_scripts
sed -i '1s@^#!.*@@' qrcode/console_scripts.py

%build
%pyproject_wheel

%install
%pyproject_install
install -Dm 644 doc/qr.1 %{buildroot}%{_mandir}/man1/qr.1
%python_clone -a %{buildroot}%{_mandir}/man1/qr.1
%python_clone -a %{buildroot}%{_bindir}/qr
%fdupes %{buildroot}%{_prefix}

%check
%pytest -s qrcode -k "not test_change"

%post
%python_install_alternative qr qr.1

%postun
%python_uninstall_alternative qr qr.1

%files %{python_files}
%license LICENSE
%doc CHANGES.rst README.rst
%python_alternative %{_bindir}/qr
%python_alternative %{_mandir}/man1/qr.1%{?ext_man}
%{python_sitelib}/qrcode
%{python_sitelib}/qrcode-%{version}.dist-info

%changelog
* Mon May  5 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 8.2.0
  * Optimize QRColorMask apply_mask method for enhanced performance
  * Fix typos on StyledPilImage embeded_* parameters.
    The old parameters with the typos are still accepted
    for backward compatibility.
- from version 8.1
  * Added support for Python 3.13.
* Wed Mar 26 2025 Ben Greiner <code@bnavigator.de>
- Fix build and runtime dependencies
* Mon Sep 30 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 8.0.0
  * Added support for Python 3.11 and 3.12.
  * Drop support for Python <=3.8.
  * Change local development setup to use Poetry_.
  * Testsuite and code quality checks are done
    through Github Actions.
  * Code quality and formatting utilises ruff_.
  * Removed ``typing_extensions`` as a dependency,
    as it's no longer required with
    having Python 3.9+ as a requirement.
  * Only allow high error correction rate (`qrcode.ERROR_CORRECT_H`)
    when generating QR codes with embedded images to ensure content
    is readable
- Install manpage manually in %%install section
- Drop 364.patch, merged upstream
- Switch package source from PyPi to Github
* Sun Jun 23 2024 Andreas Schneider <asn@cryptomilk.org>
- Fix applying the patch on Leap (SLE)
* Wed Jun 12 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Cherry-pick upstream patch to fix build with GCC 14
  * https://github.com/lincolnloop/python-qrcode/pull/364.patch
* Mon Feb  5 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add missing Requires on pypng.
- Switch to pyproject macros.
- Stop using greedy globs in %%files.
* Sun Feb  4 2024 Dirk Müller <dmueller@suse.com>
- update to 7.4.1:
  * Restructure the factory drawers, allowing different shapes in
    SVG image factories as well.
  * Add a --factory-drawer option to the qr console script.
  * Optimize the output for the SVGPathImage factory (more than 30%%
    reduction in file sizes).
  * Add a pypng image factory as a pure Python PNG solution.
    If pillow is not installed, then this becomes the default
    factory.
  * The pymaging image factory has been removed, but its
    factory shortcut and the actual PymagingImage factory class
    now just link to the PyPNGImage factory.
* Thu Nov  2 2023 Andreas Schneider <asn@cryptomilk.org>
- Use sle15_python_module_pythons
* Fri Apr  8 2022 pgajdos@suse.com
- python-mock is not required for build
* Tue Oct 26 2021 Axel Braun <axel.braun@gmx.de>
- version 7.3.1
  * Improvements for embeded image.
  * Skip color mask if QR is black and white
  * Add Styled PIL image factory, allowing different color masks and shapes in QR codes
  * Small performance inprovement
  * Add check for border size parameter
  * Add --ascii parameter to command line interface allowing to output ascii when stdout is piped
  * Add --output parameter to command line interface to specify output file
  * Accept RGB tuples in fill_color and back_color
  * Add to_string method to SVG images
  * Replace inline styles with SVG attributes to avoid CSP issues
  * Add Python3.10 to supported versions
  * Drop Python < 3.6 support.
* Tue May 19 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Wed Mar 27 2019 pgajdos@suse.com
- version update to 6.1
  * Fix short chunks of data not being optimized to the correct mode.
  * Tests fixed for Python 3
  * Fix optimize length being ignored in ``QRCode.add_data``.
  * Better calculation of the best mask pattern and related optimizations.
* Tue Jun 27 2017 jmatejek@suse.com
- pass -s to pytest, to work around bad interaction with older pytest
* Mon Jun  5 2017 jmatejek@suse.com
- convert to singlespec
- make binary python3-only
- enable tests
- add proper requirements (fixes boo#1040540)
- update to 5.3
  * better support for tty output in python3
  * --error-correction option
  * fix incomplete block table for QR version 15
  * fix BaseImage.get_image
* Sat Aug 22 2015 bruno@ioda-net.ch
- Make qr binary alternative ready (preparing for python3 packaging)
- man1 & qr alternative -py_ver to avoid conflict with python3
- Fix console_script.py missing +x
* Fri Jun  5 2015 hguo@suse.com
- Since factory project cannot make use of download_file service, the package
  no longer needs _service file to build.
* Mon Jun  1 2015 hguo@suse.com
- Upgrade to upstream release 5.1, accumulated changes:
  * Make qr script work in Windows. Thanks Ionel Cristian Mărieș
  * Fixed print_ascii function in Python 3.
  * Out-of-bounds code version numbers are handled more consistently with a ValueError.
  * Much better test coverage (now only officially supporting Python 2.6+)
  * Speed optimizations.
  * Change the output when using the qr script to use ASCII rather than just colors, better using the terminal real estate.
  * Fix a bug in passing bytecode data directly when in Python 3.
  * Substation speed optimizations to best-fit algorithm (thanks Jacob Welsh!).
  * Introduce a print_ascii method and use it as the default for the qr script rather than print_tty.
  * Update version numbers correctly.
* Sun Nov 24 2013 p.drouand@gmail.com
- Update to version 4.0.4
  + Bad version number for previous hotfix release.
- Changes from version 4.0.3
  + Fix bad QR code generation due to the regex comma fix in version 4.0.2.
- Changes from version 4.0.2
  + Fix incorrect regex causing a comma to be considered part of the
    alphanumeric set.
- Add python-setuptools BuildRequires
* Wed Oct 23 2013 axel.braun@gmx.de
- update to 4.0.1
* Wed Aug  7 2013 prusnak@opensuse.org
- updated to 3.0
* Sat May 18 2013 prusnak@opensuse.org
- updated to 2.7
* Fri Mar 29 2013 prusnak@opensuse.org
- updated to 2.5.1
* Sun Mar 17 2013 prusnak@opensuse.org
- updated to 2.5
* Sat Dec 15 2012 prusnak@opensuse.org
- created package (version 2.4.2)
